@@ -4,7 +4,7 @@
  * Author:      Vadim Zeitlin
  * Modified by:
  * Created:     2005-04-05 (extracted from wx/chkconf.h)
- * RCS-ID:      $Id: chkconf.h,v 1.5 2005/04/05 20:54:56 VZ Exp $
+ * RCS-ID:      $Id: chkconf.h,v 1.6 2005/07/30 00:34:05 VZ Exp $
  * Copyright:   (c) 2005 Vadim Zeitlin <vadim@wxwidgets.org>
  * Licence:     wxWindows licence
  */
@@ -21,6 +21,12 @@
 #    endif
 #endif
 
+#if wxUSE_STACKWALKER
+    /* not supported under Mac */
+#   undef wxUSE_STACKWALKER
+#   define wxUSE_STACKWALKER 0
+#endif /* wxUSE_STACKWALKER */
+
 #ifdef __WXMAC_CLASSIC__
 #   include "wx/mac/classic/chkconf.h"
 #else
