@@ -4,7 +4,7 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: listctrl.h,v 1.4 2005/01/14 13:02:41 ABX Exp $
+// RCS-ID:      $Id: listctrl.h,v 1.4.2.1 2006/03/10 21:37:33 RD Exp $
 // Copyright:   (c) Stefan Csomor
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -227,7 +227,10 @@ class WXDLLEXPORT wxListCtrl: public wxControl
 
   // Sets the item image
   bool SetItemImage(long item, int image, int selImage) ;
-
+#if wxABI_VERSION >= 20603
+  bool SetItemColumnImage(long item, long column, int image);
+#endif
+    
   // Gets the item text
   wxString GetItemText(long item) const ;
 
