@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     28.08.03
-// RCS-ID:      $Id: popupwin.h,v 1.3 2004/05/23 20:51:23 JS Exp $
+// RCS-ID:      $Id: popupwin.h,v 1.4 2005/08/03 00:53:09 MW Exp $
 // Copyright:   (c) 2003 Mattia Barbon
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -20,7 +20,7 @@
 // wxPopupWindow
 // ----------------------------------------------------------------------------
 
-class wxPopupWindow : public wxPopupWindowBase
+class WXDLLIMPEXP_CORE wxPopupWindow : public wxPopupWindowBase
 {
 public:
     wxPopupWindow() { Init(); }
