@@ -2,7 +2,7 @@
 // Name:        lboxtest.cpp
 // Purpose:     wxListBox sample
 // Author:      Vadim Zeitlin
-// Id:          $Id: lboxtest.cpp,v 1.10 2005/03/01 17:11:06 MW Exp $
+// Id:          $Id: lboxtest.cpp,v 1.11 2005/06/16 15:18:57 JS Exp $
 // Copyright:   (c) 2000 Vadim Zeitlin
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -521,6 +521,7 @@ void LboxTestFrame::Reset()
 
 void LboxTestFrame::CreateLbox()
 {
+    wxWindow *parent = m_lbox->GetParent();
     int flags = 0;
     switch ( m_radioSelMode->GetSelection() )
     {
@@ -540,19 +541,16 @@ void LboxTestFrame::CreateLbox()
         flags |= wxLB_SORT;
 
     wxArrayString items;
-    if ( m_lbox )
+    int count = m_lbox->GetCount();
+    for ( int n = 0; n < count; n++ )
     {
-        int count = m_lbox->GetCount();
-        for ( int n = 0; n < count; n++ )
-        {
-            items.Add(m_lbox->GetString(n));
-        }
-
-        m_sizerLbox->Detach(m_lbox);
-        delete m_lbox;
+        items.Add(m_lbox->GetString(n));
     }
 
-    m_lbox = new wxListBox(this, wxID_ANY,
+    m_sizerLbox->Detach(m_lbox);
+    delete m_lbox;
+
+    m_lbox = new wxListBox(parent, LboxTest_Listbox,
                            wxDefaultPosition, wxDefaultSize,
                            0, NULL,
                            flags);
