@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     04.11.99
-// RCS-ID:      $Id: fontmap.cpp,v 1.70 2005/03/26 21:47:54 DE Exp $
+// RCS-ID:      $Id: fontmap.cpp,v 1.71.2.1 2006/02/13 00:24:50 VZ Exp $
 // Copyright:   (c) 1999-2003 Vadim Zeitlin <vadim@wxwindows.org>
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -330,7 +330,7 @@ bool wxFontMapper::GetAltForEncoding(wxFontEncoding encoding,
 
     wxString configEntry,
              encName = GetEncodingName(encoding);
-    if ( !facename.IsEmpty() )
+    if ( !facename.empty() )
     {
         configEntry = facename + _T("_");
     }
@@ -354,13 +354,13 @@ bool wxFontMapper::GetAltForEncoding(wxFontEncoding encoding,
     }
     else // use the info entered the last time
     {
-        if ( !fontinfo.IsEmpty() && !facename.IsEmpty() )
+        if ( !fontinfo.empty() && !facename.empty() )
         {
             // we tried to find a match with facename -- now try without it
             fontinfo = GetConfig()->Read(encName);
         }
 
-        if ( !fontinfo.IsEmpty() )
+        if ( !fontinfo.empty() )
         {
             if ( info->FromString(fontinfo) )
             {
@@ -443,7 +443,6 @@ bool wxFontMapper::GetAltForEncoding(wxFontEncoding encoding,
             if ( dialog.ShowModal() == wxID_OK )
             {
                 wxFontData retData = dialog.GetFontData();
-                wxFont font = retData.GetChosenFont();
 
                 *info = retData.EncodingInfo();
                 info->encoding = retData.GetEncoding();
@@ -496,16 +495,23 @@ bool wxFontMapper::GetAltForEncoding(wxFontEncoding encoding,
                                      const wxString& facename,
                                      bool interactive)
 {
+    wxCHECK_MSG( encodingAlt, false,
+                    _T("wxFontEncoding::GetAltForEncoding(): NULL pointer") );
+
+#ifdef __WXGTK20__
+    // in GTK+ 2 we can always use UTF-8 for everything so just do it,
+    // especially as no other font encodings are currently supported
+    *encodingAlt = wxFONTENCODING_UTF8;
+    return true;
+#else // !wxGTK2
     wxNativeEncodingInfo info;
     if ( !GetAltForEncoding(encoding, &info, facename, interactive) )
         return false;
 
-    wxCHECK_MSG( encodingAlt, false,
-                    _T("wxFontEncoding::GetAltForEncoding(): NULL pointer") );
-
     *encodingAlt = info.encoding;
 
     return true;
+#endif // wxGTK2/!wxGTK2
 }
 
 bool wxFontMapper::IsEncodingAvailable(wxFontEncoding encoding,
