@@ -2,7 +2,7 @@
 // Name:        textctrl.cpp
 // Purpose:
 // Author:      Robert Roebling
-// Id:          $Id: textctrl.cpp,v 1.210 2005/06/02 08:17:57 JS Exp $
+// Id:          $Id: textctrl.cpp,v 1.217 2005/08/08 08:53:44 MR Exp $
 // Copyright:   (c) 1998 Robert Roebling, Vadim Zeitlin
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -42,7 +42,6 @@ extern bool g_isIdle;
 // data
 //-----------------------------------------------------------------------------
 
-extern bool       g_blockEventsOnDrag;
 extern wxCursor   g_globalCursor;
 extern wxWindowGTK *g_delayedFocus;
 
@@ -56,12 +55,13 @@ static void wxGtkOnRemoveTag(GtkTextBuffer *buffer,
                              GtkTextTag *tag,
                              GtkTextIter *start,
                              GtkTextIter *end,
-                             gpointer user_data)
+                             char *prefix)
 {
     gchar *name;
     g_object_get (tag, "name", &name, NULL);
 
-    if (!name || strncmp(name, "WX", 2)) // anonymous tag or not starting with "WX"
+    if (!name || strncmp(name, prefix, strlen(prefix)))
+        // anonymous tag or not starting with prefix - don't remove
         g_signal_stop_emission_by_name(buffer, "remove_tag");
 
     g_free(name);
@@ -78,7 +78,7 @@ static void wxGtkTextApplyTagsFromAttr(GtkTextBuffer *text_buffer,
     GtkTextTag *tag;
 
     gulong remove_handler_id = g_signal_connect( text_buffer, "remove_tag",
-                                                 G_CALLBACK(wxGtkOnRemoveTag), NULL);
+            G_CALLBACK(wxGtkOnRemoveTag), gpointer("WX"));
     gtk_text_buffer_remove_all_tags(text_buffer, start, end);
     g_signal_handler_disconnect( text_buffer, remove_handler_id );
 
@@ -123,6 +123,44 @@ static void wxGtkTextApplyTagsFromAttr(GtkTextBuffer *text_buffer,
                                               "background-gdk", colBg, NULL );
         gtk_text_buffer_apply_tag (text_buffer, tag, start, end);
     }
+
+    if (attr.HasAlignment())
+    {
+        GtkTextIter para_start, para_end = *end;
+        gtk_text_buffer_get_iter_at_line( text_buffer,
+                                          &para_start,
+                                          gtk_text_iter_get_line(start) );
+        gtk_text_iter_forward_line(&para_end);
+
+        remove_handler_id = g_signal_connect( text_buffer, "remove_tag",
+                                              G_CALLBACK(wxGtkOnRemoveTag),
+                                              gpointer("WXALIGNMENT"));
+        gtk_text_buffer_remove_all_tags( text_buffer, &para_start, &para_end );
+        g_signal_handler_disconnect( text_buffer, remove_handler_id );
+
+        GtkJustification align;
+        switch (attr.GetAlignment())
+        {
+            default:
+                align = GTK_JUSTIFY_LEFT;
+                break;
+            case wxTEXT_ALIGNMENT_RIGHT:
+                align = GTK_JUSTIFY_RIGHT;
+                break;
+            case wxTEXT_ALIGNMENT_CENTER:
+                align = GTK_JUSTIFY_CENTER;
+                break;
+            // gtk+ doesn't support justify as of gtk+-2.7.4
+        }
+
+        g_snprintf(buf, sizeof(buf), "WXALIGNMENT %d", align);
+        tag = gtk_text_tag_table_lookup( gtk_text_buffer_get_tag_table( text_buffer ),
+                                         buf );
+        if (!tag)
+            tag = gtk_text_buffer_create_tag( text_buffer, buf,
+                                              "justification", align, NULL );
+        gtk_text_buffer_apply_tag( text_buffer, tag, &para_start, &para_end );
+    }
 }
 }
 
@@ -883,7 +921,7 @@ void wxTextCtrl::CalculateScrollbar()
 
 wxString wxTextCtrl::GetValue() const
 {
-    wxCHECK_MSG( m_text != NULL, wxT(""), wxT("invalid text ctrl") );
+    wxCHECK_MSG( m_text != NULL, wxEmptyString, wxT("invalid text ctrl") );
 
     wxString tmp;
     if (m_windowStyle & wxTE_MULTILINE)
@@ -1071,7 +1109,7 @@ wxString wxTextCtrl::GetLineText( long lineNo ) const
 
         if (text)
         {
-            wxString buf(wxT(""));
+            wxString buf;
             long i;
             int currentLine = 0;
             for (i = 0; currentLine != lineNo && text[i]; i++ )
@@ -1092,12 +1130,12 @@ wxString wxTextCtrl::GetLineText( long lineNo ) const
 #else
         GtkTextIter line;
         gtk_text_buffer_get_iter_at_line(m_buffer,&line,lineNo);
-        GtkTextIter end;
-        gtk_text_buffer_get_end_iter(m_buffer,&end );
+        GtkTextIter end = line;
+        gtk_text_iter_forward_to_line_end(&end);
         gchar *text = gtk_text_buffer_get_text(m_buffer,&line,&end,TRUE);
         wxString result(wxGTK_CONV_BACK(text));
         g_free(text);
-        return result.BeforeFirst(wxT('\n'));
+        return result;
 #endif
     }
     else
@@ -1118,6 +1156,15 @@ bool wxTextCtrl::PositionToXY(long pos, long *x, long *y ) const
 {
     if ( m_windowStyle & wxTE_MULTILINE )
     {
+#ifdef __WXGTK20__
+        GtkTextIter iter;
+        gtk_text_buffer_get_iter_at_offset(m_buffer, &iter, pos);
+        if (gtk_text_iter_is_end(&iter))
+            return false;
+
+        *y = gtk_text_iter_get_line(&iter);
+        *x = gtk_text_iter_get_line_offset(&iter);
+#else
         wxString text = GetValue();
 
         // cast to prevent warning. But pos really should've been unsigned.
@@ -1138,6 +1185,7 @@ bool wxTextCtrl::PositionToXY(long pos, long *x, long *y ) const
             else
                 (*x)++;
         }
+#endif
     }
     else // single line control
     {
@@ -1160,17 +1208,45 @@ long wxTextCtrl::XYToPosition(long x, long y ) const
 {
     if (!(m_windowStyle & wxTE_MULTILINE)) return 0;
 
+#ifdef __WXGTK20__
+    GtkTextIter iter;
+    if (y >= gtk_text_buffer_get_line_count (m_buffer))
+        return -1;
+
+    gtk_text_buffer_get_iter_at_line(m_buffer, &iter, y);
+    if (x >= gtk_text_iter_get_chars_in_line (&iter))
+        return -1;
+
+    return gtk_text_iter_get_offset(&iter) + x;
+#else
     long pos=0;
     for( int i=0; i<y; i++ ) pos += GetLineLength(i) + 1; // one for '\n'
 
     pos += x;
     return pos;
+#endif
 }
 
 int wxTextCtrl::GetLineLength(long lineNo) const
 {
-    wxString str = GetLineText (lineNo);
-    return (int) str.Length();
+#ifdef __WXGTK20__
+    if (m_windowStyle & wxTE_MULTILINE)
+    {
+        int last_line = gtk_text_buffer_get_line_count( m_buffer ) - 1;
+        if (lineNo > last_line)
+            return -1;
+
+        GtkTextIter iter;
+        gtk_text_buffer_get_iter_at_line(m_buffer, &iter, lineNo);
+        // get_chars_in_line return includes paragraph delimiters, so need to subtract 1 IF it is not the last line
+        return gtk_text_iter_get_chars_in_line(&iter) - ((lineNo == last_line) ? 0 : 1);
+    }
+    else
+#endif
+    {
+        wxString str = GetLineText (lineNo);
+        return (int) str.Length();
+    }
 }
 
 int wxTextCtrl::GetNumberOfLines() const
@@ -1511,7 +1587,7 @@ long wxTextCtrl::GetInsertionPoint() const
     else
 #endif
     {
-    return (long) GET_EDITABLE_POS(m_text);
+        return (long) GET_EDITABLE_POS(m_text);
     }
 }
 
@@ -1725,7 +1801,7 @@ bool wxTextCtrl::IsModified() const
 
 void wxTextCtrl::Clear()
 {
-    SetValue( wxT("") );
+    SetValue( wxEmptyString );
 }
 
 void wxTextCtrl::OnChar( wxKeyEvent &key_event )
@@ -1896,6 +1972,7 @@ bool wxTextCtrl::SetStyle( long start, long end, const wxTextAttr& style )
             // nothing to do
             return true;
         }
+
 #ifdef __WXGTK20__
         gint l = gtk_text_buffer_get_char_count( m_buffer );
 
@@ -1912,8 +1989,6 @@ bool wxTextCtrl::SetStyle( long start, long end, const wxTextAttr& style )
         wxTextAttr attr = wxTextAttr::Combine(style, m_defaultStyle, this);
 
         wxGtkTextApplyTagsFromAttr( m_buffer, attr, &starti, &endi );
-
-        return true;
 #else
         // VERY dirty way to do that - removes the required text and re-adds it
         // with styling (FIXME)
@@ -1931,14 +2006,14 @@ bool wxTextCtrl::SetStyle( long start, long end, const wxTextAttr& style )
         gtk_editable_delete_text( GTK_EDITABLE(m_text), start, end );
         gtk_editable_set_position( GTK_EDITABLE(m_text), start );
 
-#if wxUSE_UNICODE
+    #if wxUSE_UNICODE
         wxWX2MBbuf buf = tmp.mbc_str();
         const char *txt = buf;
         size_t txtlen = strlen(buf);
-#else
+    #else
         const char *txt = tmp;
         size_t txtlen = tmp.length();
-#endif
+    #endif
 
         // use the attributes from style which are set in it and fall back
         // first to the default style and then to the text control default
@@ -1952,13 +2027,13 @@ bool wxTextCtrl::SetStyle( long start, long end, const wxTextAttr& style )
         gtk_editable_set_position( GTK_EDITABLE(m_text), old_pos ); */
         SetInsertionPoint( old_pos );
 #endif
+
         return true;
     }
-    else // singe line
-    {
-        // cannot do this for GTK+'s Entry widget
-        return false;
-    }
+
+    // else single line
+    // cannot do this for GTK+'s Entry widget
+    return false;
 }
 
 void wxTextCtrl::DoApplyWidgetStyle(GtkRcStyle *style)
@@ -2083,7 +2158,7 @@ void wxTextCtrl::Freeze()
             gtk_widget_set_sensitive(m_widget, false);
             g_object_ref(m_buffer);
             gtk_text_view_set_buffer(GTK_TEXT_VIEW(m_text), gtk_text_buffer_new(NULL));
-    }
+        }
 #else
         gtk_text_freeze(GTK_TEXT(m_text));
 #endif
