@@ -4,7 +4,7 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     10/21/99
-// RCS-ID:      $Id: dataobj.cpp,v 1.25 2005/08/23 07:37:13 SC Exp $
+// RCS-ID:      $Id: dataobj.cpp,v 1.25.2.1 2006/03/17 11:09:16 SC Exp $
 // Copyright:   (c) 1999 Stefan Csomor
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -339,7 +339,8 @@ bool wxBitmapDataObject::SetData(
     m_pictHandle = picHandle ;
     // ownership is transferred to the bitmap
     m_pictCreated = false ;
-    Rect frame = (**picHandle).picFrame ;
+    Rect frame ;
+    wxMacGetPictureBounds( picHandle , &frame ) ;
     
     wxMetafile mf ;
     mf.SetHMETAFILE( (WXHMETAFILE) m_pictHandle ) ;
