@@ -2,7 +2,7 @@
 // Name:        utils.cpp
 // Purpose:
 // Author:      Vaclav Slavik
-// Id:          $Id: utils.cpp,v 1.24 2005/08/30 17:25:58 ABX Exp $
+// Id:          $Id: utils.cpp,v 1.24.2.1 2006/01/27 21:54:11 MW Exp $
 // Copyright:   (c) 2001-2002 SciTech Software, Inc. (www.scitechsoft.com)
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -90,27 +90,6 @@ int wxDisplayDepth()
     return g_displayDC->getBitsPerPixel();
 }
 
-wxString wxGetOsDescription()
-{
-    wxString osname(
-
-#if defined(__UNIX__)
-        _T("Unix")
-#elif defined(__OS2__)
-        _T("OS/2")
-#elif defined(__WIN32__)
-        _T("Windows")
-#elif defined(__DOS__)
-        _T("DOS")
-#else
-        _T("unknown")
-#endif
-
-    );
-
-    return osname;
-}
-
 #if wxUSE_GUI
 
 wxToolkitInfo& wxGUIAppTraits::GetToolkitInfo()
