@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: font.cpp,v 1.32 2005/02/06 17:38:30 MBN Exp $
+// RCS-ID:      $Id: font.cpp,v 1.35 2005/07/31 09:42:13 MBN Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -46,6 +46,12 @@
 
 IMPLEMENT_DYNAMIC_CLASS(wxFont, wxGDIObject)
 
+#if wxCHECK_MOTIF_VERSION( 2, 0 ) && !wxCHECK_LESSTIF()
+    #define wxUSE_RENDER_TABLE 1
+#else
+    #define wxUSE_RENDER_TABLE 0
+#endif
+
 // ----------------------------------------------------------------------------
 // private classes
 // ----------------------------------------------------------------------------
@@ -58,10 +64,14 @@ public:
     wxXFont();
     ~wxXFont();
 
+#if !wxMOTIF_NEW_FONT_HANDLING
     WXFontStructPtr     m_fontStruct;   // XFontStruct
+#endif
+#if !wxUSE_RENDER_TABLE && !wxMOTIF_NEW_FONT_HANDLING
     WXFontList          m_fontList;     // Motif XmFontList
-#if wxCHECK_MOTIF_VERSION( 2, 0 )
+#else // if wxUSE_RENDER_TABLE
     WXRenderTable       m_renderTable;  // Motif XmRenderTable
+    WXRendition         m_rendition;    // Motif XmRendition
 #endif
     WXDisplay*          m_display;      // XDisplay
     int                 m_scale;        // Scale * 100
@@ -69,7 +79,7 @@ public:
 
 class wxFontRefData: public wxGDIRefData
 {
-friend class wxFont;
+    friend class wxFont;
 
 public:
     wxFontRefData(int size = wxDEFAULT,
@@ -126,10 +136,14 @@ protected:
 
 wxXFont::wxXFont()
 {
+#if !wxMOTIF_NEW_FONT_HANDLING
     m_fontStruct = (WXFontStructPtr) 0;
+#endif
+#if !wxUSE_RENDER_TABLE && !wxMOTIF_NEW_FONT_HANDLING
     m_fontList = (WXFontList) 0;
-#if wxCHECK_MOTIF_VERSION( 2, 0 )
+#else // if wxUSE_RENDER_TABLE
     m_renderTable = (WXRenderTable) 0;
+    m_rendition   = (WXRendition) 0;
 #endif
     m_display = (WXDisplay*) 0;
     m_scale = 100;
@@ -137,16 +151,20 @@ wxXFont::wxXFont()
 
 wxXFont::~wxXFont()
 {
-    XmFontList fontList = (XmFontList) m_fontList;
-    XmFontListFree (fontList);
-
-#if wxCHECK_MOTIF_VERSION( 2, 0 ) && !wxCHECK_LESSTIF()
-    XmRenderTable renderTable = (XmRenderTable) m_renderTable;
-    XmRenderTableFree (renderTable);
+#if !wxUSE_RENDER_TABLE
+    if (m_fontList)
+        XmFontListFree ((XmFontList) m_fontList);
+    m_fontList = NULL;
+#else // if wxUSE_RENDER_TABLE
+    if (m_renderTable)
+        XmRenderTableFree ((XmRenderTable) m_renderTable);
+    m_renderTable = NULL;
 #endif
 
     // TODO: why does freeing the font produce a segv???
     // Note that XFreeFont wasn't called in wxWin 1.68 either.
+    // MBN: probably some interaction with fonts being still
+    //      in use in some widgets...
     // XFontStruct* fontStruct = (XFontStruct*) m_fontStruct;
     //        XFreeFont((Display*) m_display, fontStruct);
 }
@@ -524,6 +542,7 @@ wxXFont* wxFont::GetInternalFont(double scale, WXDisplay* display) const
     }
 
     // not found, create a new one
+    wxString xFontSpec;
     XFontStruct *font = (XFontStruct *)
                         wxLoadQueryNearestFont(pointSize,
                                                M_FONTDATA->m_family,
@@ -531,7 +550,8 @@ wxXFont* wxFont::GetInternalFont(double scale, WXDisplay* display) const
                                                M_FONTDATA->m_weight,
                                                M_FONTDATA->m_underlined,
                                                wxT(""),
-                                               M_FONTDATA->m_encoding);
+                                               M_FONTDATA->m_encoding,
+                                               &xFontSpec);
 
     if ( !font )
     {
@@ -541,19 +561,27 @@ wxXFont* wxFont::GetInternalFont(double scale, WXDisplay* display) const
     }
 
     wxXFont* f = new wxXFont;
+#if wxMOTIF_NEW_FONT_HANDLING
+    XFreeFont( (Display*) display, font );
+#else
     f->m_fontStruct = (WXFontStructPtr)font;
+#endif
     f->m_display = ( display ? display : wxGetDisplay() );
     f->m_scale = intScale;
-    f->m_fontList = XmFontListCreate ((XFontStruct*) font, XmSTRING_DEFAULT_CHARSET);
-    M_FONTDATA->m_fonts.Append(f);
-
-#if wxCHECK_MOTIF_VERSION( 2, 0 ) && !wxCHECK_LESSTIF()
+    
+#if wxUSE_RENDER_TABLE
     XmRendition rendition;
     XmRenderTable renderTable;
     Arg args[5];
     int count = 0;
 
+#if wxMOTIF_NEW_FONT_HANDLING
+    wxChar* fontSpec = wxStrdup( xFontSpec.c_str() );
+    XtSetArg( args[count], XmNfontName, fontSpec ); ++count;
+    XtSetArg( args[count], XmNfontType, XmFONT_IS_FONTSET ); ++count;
+#else
     XtSetArg( args[count], XmNfont, font ); ++count;
+#endif
     XtSetArg( args[count], XmNunderlineType,
               GetUnderlined() ? XmSINGLE_LINE : XmNO_LINE ); ++count;
     rendition = XmRenditionCreate( XmGetXmDisplay( (Display*)f->m_display ),
@@ -563,11 +591,20 @@ wxXFont* wxFont::GetInternalFont(double scale, WXDisplay* display) const
                                               XmMERGE_REPLACE );
 
     f->m_renderTable = (WXRenderTable)renderTable;
+    f->m_rendition = (WXRendition)rendition;
+    wxASSERT( f->m_renderTable != NULL );
+#else // if !wxUSE_RENDER_TABLE
+    f->m_fontList = XmFontListCreate ((XFontStruct*) font, XmSTRING_DEFAULT_CHARSET);
+    wxASSERT( f->m_fontList != NULL );
 #endif
 
+    M_FONTDATA->m_fonts.Append(f);
+
     return f;
 }
 
+#if !wxMOTIF_NEW_FONT_HANDLING
+
 WXFontStructPtr wxFont::GetFontStruct(double scale, WXDisplay* display) const
 {
     wxXFont* f = GetInternalFont(scale, display);
@@ -577,36 +614,115 @@ WXFontStructPtr wxFont::GetFontStruct(double scale, WXDisplay* display) const
 
 WXFontList wxFont::GetFontList(double scale, WXDisplay* display) const
 {
+#if !wxUSE_RENDER_TABLE
     wxXFont* f = GetInternalFont(scale, display);
 
     return (f ? f->m_fontList : (WXFontList) 0);
+#else
+    return NULL;
+#endif
 }
 
+#endif // !wxMOTIF_NEW_FONT_HANDLING
+
+ // declared in the header, can't use wxUSE_RENDER_TABLE
 #if wxCHECK_MOTIF_VERSION( 2, 0 )
 
 WXRenderTable wxFont::GetRenderTable(WXDisplay* display) const
 {
+#if wxUSE_RENDER_TABLE
     wxXFont* f = GetInternalFont(1.0, display);
 
     return (f ? f->m_renderTable : (WXFontList) 0);
+#else
+    return NULL;
+#endif
 }
 
-#endif
+#endif // wxCHECK_MOTIF_VERSION( 2, 0 )
 
 WXFontType wxFont::GetFontType(WXDisplay* display) const
 {
-#if wxCHECK_MOTIF_VERSION( 2, 0 ) && !wxCHECK_LESSTIF()
+#if wxUSE_RENDER_TABLE
     return Ok() ? GetRenderTable(display) : NULL;
 #else
     return Ok() ? GetFontList(1.0, display) : NULL;
 #endif
 }
 
+WXFontType wxFont::GetFontTypeC(WXDisplay* display) const
+{
+#if wxUSE_RENDER_TABLE
+    return Ok() ? GetRenderTable(display) : NULL;
+#else
+    return Ok() ? XmFontListCopy( (XmFontList)GetFontList(1.0, display) ) : NULL;
+#endif
+}
+
 /*static*/ WXString wxFont::GetFontTag()
 {
-#if wxCHECK_MOTIF_VERSION( 2, 0 ) && !wxCHECK_LESSTIF()
+#if wxUSE_RENDER_TABLE
     return (WXString)XmNrenderTable;
 #else
     return (WXString)XmNfontList;
 #endif
 }
+
+#if wxMOTIF_NEW_FONT_HANDLING
+
+WXFontSet wxFont::GetFontSet(double scale, WXDisplay* display) const
+{
+    wxXFont* f = GetInternalFont(scale, display);
+
+    if( !f ) return (WXFontSet) 0;
+
+    Arg args[2];
+    int count = 0;
+
+    XtSetArg( args[count], XmNfont, 0 ); ++count;
+    XmRenditionRetrieve( (XmRendition) f->m_rendition, args, count );
+
+    return (WXFontSet) args[0].value;
+}
+
+void wxGetTextExtent(WXDisplay* display, const wxFont& font, double scale,
+                     const wxString& str,
+                     int* width, int* height, int* ascent, int* descent)
+{
+    XRectangle ink, logical;
+    WXFontSet fset = font.GetFontSet(scale, display);
+    
+    XmbTextExtents( (XFontSet)fset, str.c_str(), str.length(), &ink, &logical);
+
+    if( width ) *width = logical.width;
+    if( height ) *height = logical.height;
+    if( ascent ) *ascent = -logical.y;    
+    if( descent ) *descent = logical.height + logical.y;    
+}
+
+#else // if !wxMOTIF_NEW_FONT_HANDLING
+
+void wxGetTextExtent(WXDisplay* display, const wxFont& font,
+                     double scale, const wxString& str,
+                     int* width, int* height, int* ascent, int* descent)
+{
+    WXFontStructPtr pFontStruct = font.GetFontStruct(scale, display);
+
+    int direction, ascent2, descent2;
+    XCharStruct overall;
+    int slen = str.Len();
+
+    XTextExtents((XFontStruct*) pFontStruct, (char*) str.c_str(), slen,
+                 &direction, &ascent2, &descent2, &overall);
+
+    if ( width )
+        *width = (overall.width);
+    if ( height )
+        *height = (ascent2 + descent2);
+    if ( descent )
+        *descent = descent2;
+    if ( ascent )
+        *ascent = ascent2;
+}
+
+#endif // !wxMOTIF_NEW_FONT_HANDLING
