@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: listbox.cpp,v 1.43 2005/02/13 17:08:14 VZ Exp $
+// RCS-ID:      $Id: listbox.cpp,v 1.44 2005/06/19 19:11:20 MBN Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -95,13 +95,7 @@ bool wxListBox::Create(wxWindow *parent, wxWindowID id,
     m_backgroundColour = * wxWHITE;
 
     Widget parentWidget = (Widget) parent->GetClientWidget();
-
-    WXFontType fontType = (WXFontType)NULL;
-
-    if( m_font.Ok() )
-    {
-        fontType = m_font.GetFontType(XtDisplay(parentWidget));
-    }
+    Display* dpy = XtDisplay(parentWidget);
 
     Arg args[4];
     int count = 0;
@@ -111,9 +105,10 @@ bool wxListBox::Create(wxWindow *parent, wxWindowID id,
               ( m_windowStyle & wxLB_EXTENDED ) ? XmEXTENDED_SELECT :
                                                   XmBROWSE_SELECT );
     ++count;
-    if( fontType )
+    if( m_font.Ok() )
     {
-        XtSetArg( args[count], (String)wxFont::GetFontTag(), fontType );
+        XtSetArg( args[count],
+                  (String)wxFont::GetFontTag(), m_font.GetFontTypeC(dpy) );
         ++count;
     }
     if( m_windowStyle & wxLB_ALWAYS_SB )
