@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: menu.cpp,v 1.50 2005/05/31 11:58:04 ABX Exp $
+// RCS-ID:      $Id: menu.cpp,v 1.54 2005/09/13 16:49:06 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -173,15 +173,6 @@ bool wxMenu::ProcessCommand(wxCommandEvent & event)
 {
     bool processed = false;
 
-#if wxUSE_MENU_CALLBACK
-    // Try a callback
-    if (m_callback)
-    {
-        (void) (*(m_callback)) (*this, event);
-        processed = true;
-    }
-#endif // wxUSE_MENU_CALLBACK
-
     // Try the menu's event handler
     if ( !processed && GetEventHandler())
     {
@@ -378,7 +369,8 @@ bool wxMenuBar::CreateMenuBar(wxFrame* parent)
         return true;
     }
 
-    Widget menuBarW = XmCreateMenuBar ((Widget) parent->GetMainWidget(), "MenuBar", NULL, 0);
+    Widget menuBarW = XmCreateMenuBar ((Widget) parent->GetMainWidget(),
+                                       wxMOTIF_STR("MenuBar"), NULL, 0);
     m_mainWidget = (WXWidget) menuBarW;
 
     size_t menuCount = GetMenuCount();
@@ -492,7 +484,7 @@ WXWidget wxMenu::CreateMenu (wxMenuBar * menuBar, WXWidget parent, wxMenu * topM
 
     if (!pullDown)
     {
-        menu = XmCreatePopupMenu ((Widget) parent, "popup", args, 2);
+        menu = XmCreatePopupMenu ((Widget) parent, wxMOTIF_STR("popup"), args, 2);
 #if 0
         XtAddCallback(menu,
             XmNunmapCallback,
@@ -503,7 +495,7 @@ WXWidget wxMenu::CreateMenu (wxMenuBar * menuBar, WXWidget parent, wxMenu * topM
     else
     {
         char mnem = wxFindMnemonic (title);
-        menu = XmCreatePulldownMenu ((Widget) parent, "pulldown", args, 2);
+        menu = XmCreatePulldownMenu ((Widget) parent, wxMOTIF_STR("pulldown"), args, 2);
 
         wxString title2(wxStripMenuCodes(title));
         wxXmString label_str(title2);
@@ -656,20 +648,20 @@ void wxMenu::SetForegroundColour(const wxColour& col)
 
 void wxMenu::ChangeFont(bool keepOriginalSize)
 {
-    // Lesstif 0.87 hangs here, but 0.93 does not
-#if !wxCHECK_LESSTIF() || wxCHECK_LESSTIF_VERSION( 0, 93 )
+    // Lesstif 0.87 hangs here, but 0.93 does not; MBN: sometimes it does
+#if !wxCHECK_LESSTIF() // || wxCHECK_LESSTIF_VERSION( 0, 93 )
     if (!m_font.Ok() || !m_menuWidget)
         return;
 
-    WXFontType fontType = m_font.GetFontType(XtDisplay((Widget) m_menuWidget));
+    Display* dpy = XtDisplay((Widget) m_menuWidget);
 
     XtVaSetValues ((Widget) m_menuWidget,
-                   wxFont::GetFontTag(), fontType,
+                   wxFont::GetFontTag(), m_font.GetFontTypeC(dpy),
                    NULL);
     if (m_buttonWidget)
     {
         XtVaSetValues ((Widget) m_buttonWidget,
-                       wxFont::GetFontTag(), fontType,
+                       wxFont::GetFontTag(), m_font.GetFontTypeC(dpy),
                        NULL);
     }
 
@@ -681,7 +673,7 @@ void wxMenu::ChangeFont(bool keepOriginalSize)
         if (m_menuWidget && item->GetButtonWidget() && m_font.Ok())
         {
             XtVaSetValues ((Widget) item->GetButtonWidget(),
-                           wxFont::GetFontTag(), fontType,
+                           wxFont::GetFontTag(), m_font.GetFontTypeC(dpy),
                            NULL);
         }
         if (item->GetSubMenu())
