@@ -4,12 +4,12 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     17/09/98
-// RCS-ID:      $Id: radiobox.cpp,v 1.46 2005/09/14 14:21:16 VZ Exp $
+// RCS-ID:      $Id: radiobox.cpp,v 1.46.2.1 2006/01/08 01:29:01 SN Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
+#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA) && !defined(__EMX__)
 #pragma implementation "radiobox.h"
 #endif
 
