@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     08/08/99
-// RCS-ID:      $Id: bitmap.cpp,v 1.48 2005/05/31 09:28:38 JS Exp $
+// RCS-ID:      $Id: bitmap.cpp,v 1.52.2.1 2006/01/03 17:02:45 SN Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -65,13 +65,13 @@ void wxBitmapRefData::Free()
 {
     if ( m_pSelectedInto )
     {
-        wxLogLastError("GpiDeleteBitmap(hbitmap)");
+        wxLogLastError(wxT("GpiDeleteBitmap(hbitmap)"));
     }
     if (m_hBitmap)
     {
         if (!::GpiDeleteBitmap((HBITMAP)m_hBitmap))
         {
-            wxLogLastError("GpiDeleteBitmap(hbitmap)");
+            wxLogLastError(wxT("GpiDeleteBitmap(hbitmap)"));
         }
     }
     if (m_pBitmapMask)
@@ -88,7 +88,7 @@ void wxBitmapRefData::Free()
 // this function should be called from all wxBitmap ctors
 void wxBitmap::Init()
 {
-    m_bIsMono = FALSE;
+    m_bIsMono = false;
     //
     // True for all bitmaps created from bits, wxImages, Xpms
     //
@@ -104,7 +104,7 @@ bool wxBitmap::CopyFromIconOrCursor(
     if (!::WinQueryPointerInfo(hIcon, &SIconInfo))
     {
         wxLogLastError(wxT("WinQueryPointerInfo"));
-        return FALSE;
+        return false;
     }
     wxBitmapRefData*                pRefData = new wxBitmapRefData;
 
@@ -124,7 +124,7 @@ bool wxBitmap::CopyFromIconOrCursor(
     pMask->SetMaskBitmap(GetHBITMAP());
     SetMask(pMask);
 
-    return(TRUE);
+    return true;
 } // end of wxBitmap::CopyFromIconOrCursor
 
 bool wxBitmap::CopyFromCursor(
@@ -134,7 +134,7 @@ bool wxBitmap::CopyFromCursor(
     UnRef();
 
     if (!rCursor.Ok())
-        return(FALSE);
+        return(false);
     return(CopyFromIconOrCursor(rCursor));
 } // end of wxBitmap::CopyFromCursor
 
@@ -145,7 +145,7 @@ bool wxBitmap::CopyFromIcon(
     UnRef();
 
     if (!rIcon.Ok())
-        return(FALSE);
+        return(false);
 
     return CopyFromIconOrCursor(rIcon);
 } // end of wxBitmap::CopyFromIcon
@@ -186,7 +186,7 @@ wxBitmap::wxBitmap(
     hPs = ::GpiCreatePS(vHabmain, hDc, &vSize, GPIA_ASSOC | PU_PELS);
     if (hPs == 0)
     {
-        wxLogLastError("GpiCreatePS Failure");
+        wxLogLastError(wxT("GpiCreatePS Failure"));
     }
 
     if (nDepth == 1)
@@ -211,14 +211,14 @@ wxBitmap::wxBitmap(
         {
             for (nCols = 0; nCols < nBytesPerLine; nCols++)
             {
-                unsigned char       ucVal = *pzSrc++;
-                unsigned char       ucReversed = 0;
-                int                 nBits;
+                unsigned char ucVal = *pzSrc++;
+                unsigned char ucReversed = 0;
+                int nBits;
 
                 for (nBits = 0; nBits < 8; nBits++)
                 {
                     ucReversed <<= 1;
-                    ucReversed |= (ucVal & 0x01);
+                    ucReversed = (unsigned char)(ucReversed | (ucVal & 0x01));
                     ucVal >>= 1;
                 }
                 *pzDst++ = ucReversed;
@@ -242,7 +242,7 @@ wxBitmap::wxBitmap(
     vHeader.cx              = (USHORT)nWidth;
     vHeader.cy              = (USHORT)nHeight;
     vHeader.cPlanes         = 1L;
-    vHeader.cBitCount       = nDepth;
+    vHeader.cBitCount       = (USHORT)nDepth;
     vHeader.usReserved      = 0;
 
     memset(&vInfo, '\0', 16);
@@ -250,13 +250,13 @@ wxBitmap::wxBitmap(
     vInfo.cx              = (USHORT)nWidth;
     vInfo.cy              = (USHORT)nHeight;
     vInfo.cPlanes         = 1L;
-    vInfo.cBitCount       = nDepth;
+    vInfo.cBitCount       = (USHORT)nDepth;
 
     HBITMAP                         hBmp = ::GpiCreateBitmap(hPs, &vHeader, CBM_INIT, (PBYTE)pzData, &vInfo);
 
     if (!hBmp)
     {
-        wxLogLastError("CreateBitmap");
+        wxLogLastError(wxT("CreateBitmap"));
     }
     ::GpiDestroyPS(hPs);
     ::DevCloseDC(hDc);
@@ -334,7 +334,7 @@ bool wxBitmap::Create(
         HPS                         hPS   = ::GpiCreatePS(vHabmain, hDC, &vSize, PU_PELS | GPIA_ASSOC);
 
         if (nD == 1)
-            m_bIsMono = TRUE;
+            m_bIsMono = true;
         memset(&vHeader, '\0', 16);
         vHeader.cbFix     =  16;
         vHeader.cx        = nW;
@@ -369,7 +369,7 @@ bool wxBitmap::Create(
         vHeader.cx        = nW;
         vHeader.cy        = nH;
         vHeader.cPlanes   = 1;
-        vHeader.cBitCount = lBitCount;
+        vHeader.cBitCount = (USHORT)lBitCount;
 
         hBmp = ::GpiCreateBitmap( hPSScreen
                                  ,&vHeader
@@ -393,20 +393,48 @@ bool wxBitmap::CreateFromXpm(
 #if wxUSE_IMAGE && wxUSE_XPM
     Init();
 
-    wxCHECK_MSG(ppData != NULL, FALSE, wxT("invalid bitmap data"))
+    wxCHECK_MSG(ppData != NULL, false, wxT("invalid bitmap data"))
 
     wxXPMDecoder                    vDecoder;
     wxImage                         vImg = vDecoder.ReadData(ppData);
 
-    wxCHECK_MSG(vImg.Ok(), FALSE, wxT("invalid bitmap data"))
+    wxCHECK_MSG(vImg.Ok(), false, wxT("invalid bitmap data"))
 
     *this = wxBitmap(vImg);
-    return TRUE;
+    return true;
 #else
-    return FALSE;
+    return false;
 #endif
 } // end of wxBitmap::CreateFromXpm
 
+bool wxBitmap::LoadFile(const wxString& filename, long type)
+{
+    UnRef();
+
+    wxBitmapHandler *handler = wxDynamicCast(FindHandler(type), wxBitmapHandler);
+
+    if ( handler )
+    {
+        m_refData = new wxBitmapRefData;
+
+        return handler->LoadFile(this, filename, type, -1, -1);
+    }
+#if wxUSE_IMAGE
+    else // no bitmap handler found
+    {
+        wxImage image;
+        if ( image.LoadFile( filename, type ) && image.Ok() )
+        {
+            *this = wxBitmap(image);
+
+            return true;
+        }
+    }
+#endif // wxUSE_IMAGE
+
+    return false;
+}
+
 bool wxBitmap::LoadFile(
   int                               nId
 , long                              lType
@@ -431,7 +459,7 @@ bool wxBitmap::LoadFile(
     }
     else
     {
-        return(FALSE);
+        return false;
     }
 } // end of wxBitmap::LoadFile
 
@@ -453,7 +481,7 @@ bool wxBitmap::Create(
     {
         wxLogDebug(wxT("Failed to create bitmap: no bitmap handler for type %ld defined."), lType);
 
-        return(FALSE);
+        return false;
     }
 
     m_refData = new wxBitmapRefData;
@@ -491,7 +519,7 @@ bool wxBitmap::SaveFile(
         wxImage                     vImage = ConvertToImage();
 
         if (!vImage.Ok())
-            return(FALSE);
+            return false;
 
         return(vImage.SaveFile( rFilename
                                ,lType
@@ -509,7 +537,7 @@ bool wxBitmap::CreateFromImage (
 , int                               nDepth
 )
 {
-    wxCHECK_MSG(rImage.Ok(), FALSE, wxT("invalid image"));
+    wxCHECK_MSG(rImage.Ok(), false, wxT("invalid image"));
     m_refData = new wxBitmapRefData();
 
     int                             nSizeLimit = 1024 * 768 * 3;
@@ -546,13 +574,13 @@ bool wxBitmap::CreateFromImage (
     //
     // Set bitmap parameters
     //
-    wxCHECK_MSG(rImage.Ok(), FALSE, wxT("invalid image"));
+    wxCHECK_MSG(rImage.Ok(), false, wxT("invalid image"));
     SetWidth(nWidth);
     SetHeight(nBmpHeight);
     if (nDepth == 1)
-        m_bIsMono = TRUE;
+        m_bIsMono = true;
     else
-        m_bIsMono = FALSE;
+        m_bIsMono = false;
     if (nDepth == -1)
         nDepth = wxDisplayDepth();
     SetDepth(nDepth);
@@ -589,7 +617,7 @@ bool wxBitmap::CreateFromImage (
     if(!pucBits)
     {
         wxFAIL_MSG(wxT("could not allocate memory for DIB"));
-        return FALSE;
+        return false;
     }
     memset(pucBits, '\0', (nBytePerLine * nHeight));
 
@@ -829,7 +857,7 @@ bool wxBitmap::CreateFromImage (
     ::DevCloseDC(hDCScreen);
     ::DevCloseDC(hDC);
     free(pucBits);
-    return TRUE;
+    return true;
 } // end of wxBitmap::CreateFromImage
 
 wxImage wxBitmap::ConvertToImage() const
@@ -860,7 +888,7 @@ wxImage wxBitmap::ConvertToImage() const
     HBITMAP                         hOldBitmap;
     DEVOPENSTRUC                    vDop  = {0L, "DISPLAY", NULL, 0L, 0L, 0L, 0L, 0L, 0L};
     SIZEL                           vSizlPage = {0,0};
-    HDC                             hDCMem = NULLHANDLE;;
+    HDC                             hDCMem = NULLHANDLE;
 
     vImage.Create( nWidth
                   ,nHeight
@@ -1044,11 +1072,11 @@ wxImage wxBitmap::ConvertToImage() const
                              ,ucGreen
                              ,ucBlue
                             );
-        vImage.SetMask(TRUE);
+        vImage.SetMask(true);
     }
     else
     {
-        vImage.SetMask(FALSE);
+        vImage.SetMask(false);
     }
 
     //
@@ -1181,9 +1209,7 @@ void wxBitmap::SetMask(
     GetBitmapData()->m_pBitmapMask = pMask;
 } // end of wxBitmap::SetMask
 
-wxBitmap wxBitmap::GetBitmapForDC(
-  wxDC&                             rDc
-) const
+wxBitmap wxBitmap::GetBitmapForDC(wxDC& WXUNUSED(rDc)) const
 {
     return(*this);
 } // end of wxBitmap::GetBitmapForDC
@@ -1261,7 +1287,7 @@ bool wxMask::Create(
     }
     if (!rBitmap.Ok() || rBitmap.GetDepth() != 1)
     {
-        return(FALSE);
+        return false;
     }
 
     memset(&vBmih, '\0', sizeof(BITMAPINFOHEADER2));
@@ -1292,7 +1318,7 @@ bool wxMask::Create(
     ::GpiDestroyPS(hPSDst);
     ::DevCloseDC(hDCSrc);
     ::DevCloseDC(hDCDst);
-    return(TRUE);
+    return true;
 } // end of wxMask::Create
 
 // Create a mask from a bitmap and a palette index indicating
@@ -1329,7 +1355,7 @@ bool wxMask::Create(
                           ));
         }
     }
-    return(FALSE);
+    return false;
 } // end of wxMask::Create
 
 // Create a mask from a bitmap and a colour indicating
@@ -1339,7 +1365,7 @@ bool wxMask::Create(
 , const wxColour&                   rColour
 )
 {
-    bool                            bOk = TRUE;
+    bool                            bOk = true;
     COLORREF                        vMaskColour = OS2RGB( rColour.Red()
                                                          ,rColour.Green()
                                                          ,rColour.Blue()
@@ -1359,7 +1385,7 @@ bool wxMask::Create(
     }
     if (!rBitmap.Ok())
     {
-        return(FALSE);
+        return false;
     }
 
     //
@@ -1400,7 +1426,7 @@ bool wxMask::Create(
                 //
                 // Doesn't make sense to continue
                 //
-                bOk = FALSE;
+                bOk = false;
                 break;
             }
 
@@ -1422,32 +1448,30 @@ bool wxMask::Create(
     ::GpiDestroyPS(hPSDst);
     ::DevCloseDC(hDCSrc);
     ::DevCloseDC(hDCDst);
-    return(TRUE);
+    return true;
 } // end of wxMask::Create
 
 // ----------------------------------------------------------------------------
 // wxBitmapHandler
 // ----------------------------------------------------------------------------
 
-bool wxBitmapHandler::Create(
-  wxGDIImage*                       pImage
-, void*                             pData
-, long                              lFlags
-, int                               nWidth
-, int                               nHeight
-, int                               nDepth
-)
+bool wxBitmapHandler::Create( wxGDIImage* pImage,
+                              void*       pData,
+                              long        WXUNUSED(lFlags),
+                              int         nWidth,
+                              int         nHeight,
+                              int         nDepth)
 {
-    wxBitmap*                       pBitmap = wxDynamicCast( pImage
-                                                            ,wxBitmap
-                                                           );
+    wxBitmap* pBitmap = wxDynamicCast( pImage
+                                      ,wxBitmap
+                                       );
 
     return(pBitmap ? Create( pBitmap
                             ,pData
                             ,nWidth
                             ,nHeight
                             ,nDepth
-                           ) : FALSE);
+                           ) : false);
 }
 
 bool wxBitmapHandler::Load(
@@ -1467,7 +1491,7 @@ bool wxBitmapHandler::Load(
                               ,lFlags
                               ,nWidth
                               ,nHeight
-                             ) : FALSE);
+                             ) : false);
 }
 
 bool wxBitmapHandler::Save(
@@ -1483,7 +1507,7 @@ bool wxBitmapHandler::Save(
     return(pBitmap ? SaveFile( pBitmap
                               ,rName
                               ,lType
-                             ) : FALSE);
+                             ) : false);
 }
 
 bool wxBitmapHandler::Create(
@@ -1495,7 +1519,7 @@ bool wxBitmapHandler::Create(
 , int                               WXUNUSED(nDepth)
 )
 {
-    return(FALSE);
+    return false;
 }
 
 bool wxBitmapHandler::LoadFile(
@@ -1506,7 +1530,18 @@ bool wxBitmapHandler::LoadFile(
 , int                               WXUNUSED(nDesiredHeight)
 )
 {
-    return(FALSE);
+    return false;
+}
+
+bool wxBitmapHandler::LoadFile(
+  wxBitmap*                         WXUNUSED(pBitmap)
+, const wxString&                   WXUNUSED(rName)
+, long                              WXUNUSED(lType)
+, int                               WXUNUSED(nDesiredWidth)
+, int                               WXUNUSED(nDesiredHeight)
+)
+{
+    return false;
 }
 
 bool wxBitmapHandler::SaveFile(
@@ -1516,7 +1551,7 @@ bool wxBitmapHandler::SaveFile(
 , const wxPalette*                  WXUNUSED(pPalette)
 )
 {
-    return(FALSE);
+    return false;
 }
 
 // ----------------------------------------------------------------------------
@@ -1590,3 +1625,79 @@ HBITMAP wxInvertMask(
     return hBmpInvMask;
 } // end of WxWinGdi_InvertMask
 
+HBITMAP wxFlipBmp( HBITMAP hBmp, int nWidth, int nHeight )
+{
+    wxCHECK_MSG( hBmp, 0, _T("invalid bitmap in wxFlipBmp") );
+
+    //
+    // Get width/height from the bitmap if not given
+    //
+    if (!nWidth || !nHeight)
+    {
+        BITMAPINFOHEADER2 vBmhdr;
+
+        vBmhdr.cbFix  = 16;
+        ::GpiQueryBitmapInfoHeader( hBmp,
+                                    &vBmhdr );
+        nWidth        = (int)vBmhdr.cx;
+        nHeight       = (int)vBmhdr.cy;
+    }
+
+    BITMAPINFOHEADER2 vBmih;
+    SIZEL             vSize     = {0, 0};
+    DEVOPENSTRUC      vDop      = {0L, "DISPLAY", NULL, 0L, 0L, 0L, 0L, 0L, 0L};
+    HDC               hDCSrc    = ::DevOpenDC(  vHabmain,
+                                                OD_MEMORY,
+                                                "*",
+                                                5L,
+                                                (PDEVOPENDATA)&vDop,
+                                                NULLHANDLE  );
+    HDC               hDCDst    = ::DevOpenDC(  vHabmain,
+                                                OD_MEMORY,
+                                                "*",
+                                                5L,
+                                                (PDEVOPENDATA)&vDop,
+                                                NULLHANDLE  );
+    HPS               hPSSrc    = ::GpiCreatePS(  vHabmain,
+                                                  hDCSrc,
+                                                  &vSize,
+                                                  PU_PELS | GPIA_ASSOC  );
+    HPS               hPSDst    = ::GpiCreatePS(  vHabmain,
+                                                  hDCDst,
+                                                  &vSize,
+                                                  PU_PELS | GPIA_ASSOC  );
+    POINTL            vPoint[4] = { {0,      nHeight},
+                                    {nWidth, 0},
+                                    {0,      0},
+                                    {nWidth, nHeight} };
+
+    memset(&vBmih, '\0', 16);
+    vBmih.cbFix     = 16;
+    vBmih.cx        = nWidth;
+    vBmih.cy        = nHeight;
+    vBmih.cPlanes   = 1;
+    vBmih.cBitCount = 24;
+
+    HBITMAP hInvBmp = ::GpiCreateBitmap(  hPSDst,
+                                          &vBmih,
+                                          0L,
+                                          NULL,
+                                          NULL  );
+
+    ::GpiSetBitmap(hPSSrc, (HBITMAP) hBmp);
+    ::GpiSetBitmap(hPSDst, (HBITMAP) hInvBmp);
+
+    ::GpiBitBlt(  hPSDst,
+                  hPSSrc,
+                  4L,
+                  vPoint,
+                  ROP_SRCCOPY,
+                  BBO_IGNORE  );
+
+    ::GpiDestroyPS(hPSSrc);
+    ::GpiDestroyPS(hPSDst);
+    ::DevCloseDC(hDCSrc);
+    ::DevCloseDC(hDCDst);
+
+    return hInvBmp;
+} // end of wxFlipBmp
