@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     10/13/99
-// RCS-ID:      $Id: choice.cpp,v 1.30 2005/04/27 01:19:38 DW Exp $
+// RCS-ID:      $Id: choice.cpp,v 1.31.2.1 2006/01/07 18:01:19 SN Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -94,18 +94,11 @@ bool wxChoice::Create(
     {
         Append(asChoices[i]);
     }
-    wxFont*                          pTextFont = new wxFont( 10
-                                                            ,wxMODERN
-                                                            ,wxNORMAL
-                                                            ,wxNORMAL
-                                                           );
-    SetFont(*pTextFont);
     SetSize( rPos.x
             ,rPos.y
             ,rSize.x
             ,rSize.y
            );
-    delete pTextFont;
     return true;
 } // end of wxChoice::Create
 
@@ -327,13 +320,11 @@ wxClientData* wxChoice::DoGetItemClientObject(
 // wxOS2 specific helpers
 // ----------------------------------------------------------------------------
 
-void wxChoice::DoSetSize(
-  int                               nX
-, int                               nY
-, int                               nWidth
-, int                               nHeight
-, int                               nSizeFlags
-)
+void wxChoice::DoSetSize(int nX,
+                         int nY,
+                         int nWidth,
+                         int WXUNUSED(nHeight),
+                         int nSizeFlags)
 {
     //
     // Ignore height parameter because height doesn't mean 'initially
@@ -345,7 +336,7 @@ void wxChoice::DoSetSize(
     wxControl::DoSetSize( nX
                          ,nY
                          ,nWidth
-                         ,-1
+                         ,wxDefaultCoord
                          ,nSizeFlags
                         );
 } // end of wxChoice::DoSetSize
