@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     01/21/03
-// RCS-ID:      $Id: listctrl.cpp,v 1.13 2005/04/08 14:34:16 MW Exp $
+// RCS-ID:      $Id: listctrl.cpp,v 1.13.2.3 2006/03/10 21:37:16 RD Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -1548,15 +1548,27 @@ bool wxListCtrl::SetItemImage (
   long                              lItem
 , int                               nImage
 , int                               WXUNUSED(nSelImage))
+{
+    return SetItemColumnInfo(lItem, 0, nImage);
+} // end of wxListCtrl::SetItemImage
+
+#if wxABI_VERSION >= 20603
+// Sets the item image
+bool wxListCtrl::SetItemColumnImage (
+  long                              lItem
+, long                              lColumn
+, int                               nImage
 {
     wxListItem                      vInfo;
 
     vInfo.m_mask   = wxLIST_MASK_IMAGE;
     vInfo.m_image  = nImage;
     vInfo.m_itemId = lItem;
+    vInfo.m_col    = lColumn;
     return SetItem(vInfo);
-} // end of wxListCtrl::SetItemImage
-
+} // end of wxListCtrl::SetItemColumnImage
+#endif
+  
 // Gets the item text
 wxString wxListCtrl::GetItemText (
   long                              lItem
