@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     ??/??/98
-// RCS-ID:      $Id: statbox.cpp,v 1.18 2005/04/27 01:19:42 DW Exp $
+// RCS-ID:      $Id: statbox.cpp,v 1.20 2006/01/06 22:26:15 SN Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -65,24 +65,20 @@ bool wxStaticBox::Create(
     SetBackgroundColour(GetParent()->GetBackgroundColour());
 
     wxColour                        vColour;
-
     vColour.Set(wxString(wxT("BLACK")));
-
     LONG                            lColor = (LONG)vColour.GetPixel();
-
     ::WinSetPresParam( m_hWnd
                       ,PP_FOREGROUNDCOLOR
                       ,sizeof(LONG)
                       ,(PVOID)&lColor
                      );
-    lColor = (LONG)m_backgroundColour.GetPixel();
 
+    lColor = (LONG)m_backgroundColour.GetPixel();
     ::WinSetPresParam( m_hWnd
                       ,PP_BACKGROUNDCOLOR
                       ,sizeof(LONG)
                       ,(PVOID)&lColor
                      );
-    SetFont(*wxSMALL_FONT);
     SetSize( rPos.x
             ,rPos.y
             ,rSize.x
@@ -96,16 +92,12 @@ wxSize wxStaticBox::DoGetBestSize() const
     int                             nCx;
     int                             nCy;
     int                             wBox;
-    wxFont                          vFont = GetFont();
 
-    wxGetCharSize( GetHWND()
-                  ,&nCx
-                  ,&nCy
-                  ,&vFont
-                 );
+    nCx = GetCharWidth();
+    nCy = GetCharHeight();
     GetTextExtent( wxGetWindowText(m_hWnd)
                   ,&wBox
-                  ,&nCy
+                  ,NULL
                  );
     wBox += 3 * nCx;
 
