@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     30.12.01
-// RCS-ID:      $Id: toplevel.cpp,v 1.37 2005/04/27 01:19:43 DW Exp $
+// RCS-ID:      $Id: toplevel.cpp,v 1.38.2.2 2006/01/11 22:35:06 SN Exp $
 // Copyright:   (c) 2001 SciTech Software, Inc. (www.scitechsoft.com)
 // License:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -38,6 +38,7 @@
     #include "wx/frame.h"
     #include "wx/control.h"
     #include "wx/containr.h"        // wxSetFocusToChild()
+    #include "wx/settings.h"
 #endif //WX_PRECOMP
 
 #include "wx/module.h"        // wxSetFocusToChild()
@@ -56,7 +57,7 @@
 extern void          wxAssociateWinWithHandle( HWND         hWnd
                                               ,wxWindowOS2* pWin
                                              );
-bool                 wxTopLevelWindowOS2::m_sbInitialized = FALSE;
+bool                 wxTopLevelWindowOS2::m_sbInitialized = false;
 wxWindow*            wxTopLevelWindowOS2::m_spHiddenParent = NULL;
 
 // ============================================================================
@@ -136,19 +137,19 @@ IMPLEMENT_DYNAMIC_CLASS(wxTLWHiddenParentModule, wxModule)
 
 void wxTopLevelWindowOS2::Init()
 {
-    m_bIconized = m_bMaximizeOnShow = FALSE;
+    m_bIconized = m_bMaximizeOnShow = false;
 
     //
     // Unlike (almost?) all other windows, frames are created hidden
     //
-    m_isShown = FALSE;
+    m_isShown = false;
 
     //
     // Data to save/restore when calling ShowFullScreen
     m_lFsStyle          = 0;
     m_lFsOldWindowStyle = 0;
-    m_bFsIsMaximized    = FALSE;
-    m_bFsIsShowing      = FALSE;
+    m_bFsIsMaximized    = false;
+    m_bFsIsShowing      = false;
 
     m_hFrame    = NULLHANDLE;
     memset(&m_vSwp, 0, sizeof(SWP));
@@ -307,12 +308,11 @@ WXHWND wxTopLevelWindowOS2::OS2GetParent() const
     return (WXHWND)hWndParent;
 } // end of wxTopLevelWindowOS2::OS2GetParent
 
-bool wxTopLevelWindowOS2::CreateDialog(
-  ULONG                             ulDlgTemplate
-, const wxString&                   rsTitle
-, const wxPoint&                    rPos
-, const wxSize&                     rSize
-)
+
+bool wxTopLevelWindowOS2::CreateDialog( ULONG           ulDlgTemplate,
+                                        const wxString& WXUNUSED(rsTitle),
+                                        const wxPoint&  rPos,
+                                        const wxSize&   rSize )
 {
     wxWindow*                       pParent = GetParent();
 
@@ -365,7 +365,7 @@ bool wxTopLevelWindowOS2::CreateDialog(
 
         wxLogSysError(wxT("Can't create dialog using template '%ld'"), ulDlgTemplate);
 
-        return FALSE;
+        return false;
     }
 
     //
@@ -413,7 +413,7 @@ bool wxTopLevelWindowOS2::CreateDialog(
         nX = (vSizeDpy.x - nWidth) / 2;
         nY = (vSizeDpy.y - nHeight) / 2;
     }
-    m_backgroundColour.Set(wxString(wxT("LIGHT GREY")));
+    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_APPWORKSPACE));
 
     LONG                            lColor = (LONG)m_backgroundColour.GetPixel();
 
@@ -423,9 +423,12 @@ bool wxTopLevelWindowOS2::CreateDialog(
                            ,(PVOID)&lColor
                           ))
     {
-        return FALSE;
+        return false;
     }
 
+    // Convert to OS/2 coordinates
+    nY = GetOS2ParentHeight(pParent) - nY - nHeight;
+
     ::WinSetWindowPos( GetHwnd()
                       ,HWND_TOP
                       ,nX
@@ -437,7 +440,7 @@ bool wxTopLevelWindowOS2::CreateDialog(
     ::WinQueryWindowPos(GetHwnd(), GetSwp());
     m_hFrame = m_hWnd;
     SubclassWin(m_hWnd);
-    return TRUE;
+    return true;
 } // end of wxTopLevelWindowOS2::CreateDialog
 
 bool wxTopLevelWindowOS2::CreateFrame(
@@ -475,7 +478,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
     // Clear the visible flag, we always call show
     //
     ulStyleFlags &= (unsigned long)~WS_VISIBLE;
-    m_bIconized = FALSE;
+    m_bIconized = false;
 
     //
     // Create the frame window:  We break ranks with other ports now
@@ -499,7 +502,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
         vError = ::WinGetLastError(vHabmain);
         sError = wxPMErrorToStr(vError);
         wxLogError(_T("Error creating frame. Error: %s\n"), sError.c_str());
-        return FALSE;
+        return false;
     }
 
     //
@@ -510,7 +513,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
     wxAssociateWinWithHandle(m_hWnd, this);
     wxAssociateWinWithHandle(m_hFrame, this);
 
-    m_backgroundColour.Set(wxString(wxT("MEDIUM GREY")));
+    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_APPWORKSPACE));
 
     LONG                            lColor = (LONG)m_backgroundColour.GetPixel();
 
@@ -523,7 +526,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
         vError = ::WinGetLastError(vHabmain);
         sError = wxPMErrorToStr(vError);
         wxLogError(_T("Error creating frame. Error: %s\n"), sError.c_str());
-        return FALSE;
+        return false;
     }
 
     //
@@ -537,17 +540,47 @@ bool wxTopLevelWindowOS2::CreateFrame(
     // Now size everything.  If adding a menu the client will need to be resized.
     //
 
-    if (pParent)
-    {
-        nY = pParent->GetSize().y - (nY + nHeight);
-    }
-    else
-    {
-        RECTL                   vRect;
+    if (!OS2GetCreateWindowCoords( rPos
+                                  ,rSize
+                                  ,nX
+                                  ,nY
+                                  ,nWidth
+                                  ,nHeight
+                                 ))
+        nX = nWidth = (int)CW_USEDEFAULT;
 
-        ::WinQueryWindowRect(HWND_DESKTOP, &vRect);
-        nY = vRect.yTop - (nY + nHeight);
+    //
+    // We can't use CW_USEDEFAULT here as we're not calling CreateWindow()
+    // and passing CW_USEDEFAULT to MoveWindow() results in resizing the
+    // window to (0, 0) size which breaks quite a lot of things, e.g. the
+    // sizer calculation in wxSizer::Fit()
+    //
+    if (nWidth == (int)CW_USEDEFAULT)
+    {
+        //
+        // The exact number doesn't matter, the dialog will be resized
+        // again soon anyhow but it should be big enough to allow
+        // calculation relying on "totalSize - clientSize > 0" work, i.e.
+        // at least greater than the title bar height
+        //
+        nWidth = nHeight = 100;
     }
+    if (nX == (int)CW_USEDEFAULT)
+    {
+        //
+        // Centre it on the screen for now - what else can we do?
+        // TODO: We could try FCF_SHELLPOSITION but it will require moving
+        //       things around a bit.
+        //
+        wxSize                      vSizeDpy = wxGetDisplaySize();
+
+        nX = (vSizeDpy.x - nWidth) / 2;
+        nY = (vSizeDpy.y - nHeight) / 2;
+    }
+
+    // Convert to OS/2 coordinates
+    nY = GetOS2ParentHeight(pParent) - nY - nHeight;
+
     if (!::WinSetWindowPos( m_hFrame
                            ,HWND_TOP
                            ,nX
@@ -560,7 +593,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
         vError = ::WinGetLastError(vHabmain);
         sError = wxPMErrorToStr(vError);
         wxLogError(_T("Error sizing frame. Error: %s\n"), sError.c_str());
-        return FALSE;
+        return false;
     }
     lStyle =  ::WinQueryWindowULong( m_hWnd
                                     ,QWL_STYLE
@@ -570,7 +603,7 @@ bool wxTopLevelWindowOS2::CreateFrame(
                         ,QWL_STYLE
                         ,lStyle
                        );
-    return TRUE;
+    return true;
 } // end of wxTopLevelWindowOS2::CreateFrame
 
 bool wxTopLevelWindowOS2::Create(
@@ -610,7 +643,7 @@ bool wxTopLevelWindowOS2::Create(
     if (GetExtraStyle() & wxTOPLEVEL_EX_DIALOG)
     {
         //
-        // We have different dialog templates to allows creation of dialogs
+        // We have different dialog templates to allow creation of dialogs
         // with & without captions under OS2indows, resizeable or not (but a
         // resizeable dialog always has caption - otherwise it would look too
         // strange)
@@ -731,14 +764,14 @@ bool wxTopLevelWindowOS2::Show(
     }
     else
     {
-        return FALSE;
+        return false;
     }
     if (bShow)
     {
         if (m_bMaximizeOnShow)
         {
             nShowCmd = SWP_MAXIMIZE;
-            m_bMaximizeOnShow = FALSE;
+            m_bMaximizeOnShow = false;
         }
         else
         {
@@ -753,19 +786,15 @@ bool wxTopLevelWindowOS2::Show(
 
     if (bShow)
     {
-        wxActivateEvent             vEvent(wxEVT_ACTIVATE, TRUE, m_windowId);
+        wxActivateEvent             vEvent(wxEVT_ACTIVATE, true, m_windowId);
 
         ::WinQueryWindowPos(m_hFrame, &vSwp);
-        m_bIconized = vSwp.fl & SWP_MINIMIZE;
+        m_bIconized = ( vSwp.fl & SWP_MINIMIZE ) == SWP_MINIMIZE ;
         ::WinQueryWindowPos(m_hWnd, &m_vSwpClient);
         ::WinSendMsg(m_hFrame, WM_UPDATEFRAME, (MPARAM)~0, 0);
         ::WinQueryWindowPos(m_hWnd, &vSwp);
-        ::WinEnableWindow(m_hFrame, TRUE);
+        ::WinEnableWindow(m_hFrame, true);
 
-        //
-        // Deal with children
-        //
-        MoveChildren(m_vSwpClient.cy - vSwp.cy);
         vEvent.SetEventObject(this);
         GetEventHandler()->ProcessEvent(vEvent);
     }
@@ -779,11 +808,11 @@ bool wxTopLevelWindowOS2::Show(
             HWND                    hWndParent = GetHwndOf(GetParent());
 
             ::WinQueryWindowPos(hWndParent, &vSwp);
-            m_bIconized = vSwp.fl & SWP_MINIMIZE;
+            m_bIconized = (vSwp.fl & SWP_MINIMIZE)==SWP_MINIMIZE;
             ::WinEnableWindow(hWndParent, TRUE);
         }
     }
-    return TRUE;
+    return true;
 } // end of wxTopLevelWindowOS2::Show
 
 // ----------------------------------------------------------------------------
@@ -813,9 +842,8 @@ void wxTopLevelWindowOS2::Maximize(
 
 bool wxTopLevelWindowOS2::IsMaximized() const
 {
-
     ::WinQueryWindowPos(m_hFrame, (PSWP)&m_vSwp);
-    return (m_vSwp.fl & SWP_MAXIMIZE);
+    return (m_vSwp.fl & SWP_MAXIMIZE) == SWP_MAXIMIZE;
 } // end of wxTopLevelWindowOS2::IsMaximized
 
 void wxTopLevelWindowOS2::Iconize(
@@ -830,9 +858,9 @@ bool wxTopLevelWindowOS2::IsIconized() const
     // also update the current state
     ::WinQueryWindowPos(m_hFrame, (PSWP)&m_vSwp);
     if (m_vSwp.fl & SWP_MINIMIZE)
-        ((wxTopLevelWindow*)this)->m_bIconized = TRUE;
+        ((wxTopLevelWindow*)this)->m_bIconized = true;
     else
-        ((wxTopLevelWindow*)this)->m_bIconized = FALSE;
+        ((wxTopLevelWindow*)this)->m_bIconized = false;
     return m_bIconized;
 } // end of wxTopLevelWindowOS2::IsIconized
 
@@ -860,17 +888,15 @@ void wxTopLevelWindowOS2::SendSizeEvent()
 // wxTopLevelWindowOS2 fullscreen
 // ----------------------------------------------------------------------------
 
-bool wxTopLevelWindowOS2::ShowFullScreen(
-  bool                              bShow
-, long                              lStyle
-)
+bool wxTopLevelWindowOS2::ShowFullScreen( bool bShow,
+                                          long lStyle )
 {
     if (bShow)
     {
         if (IsFullScreen())
-            return FALSE;
+            return false;
 
-        m_bFsIsShowing = TRUE;
+        m_bFsIsShowing = true;
         m_lFsStyle = lStyle;
 
         //
@@ -893,8 +919,8 @@ bool wxTopLevelWindowOS2::ShowFullScreen(
         //
         // Decide which window lStyle flags to turn off
         //
-        LONG                        lNewStyle = m_lFsOldWindowStyle;
-        LONG                        lOffFlags = 0;
+        LONG lNewStyle = m_lFsOldWindowStyle;
+        LONG lOffFlags = 0;
 
         if (lStyle & wxFULLSCREEN_NOBORDER)
             lOffFlags |= FCF_BORDER;
@@ -914,16 +940,14 @@ bool wxTopLevelWindowOS2::ShowFullScreen(
         //
         // Resize to the size of the desktop
         //
-        int                         nWidth;
-        int                         nHeight;
-        RECTL                       vRect = wxGetWindowRect(HWND_DESKTOP);
+        int   nWidth;
+        int   nHeight;
+        RECTL vRect = wxGetWindowRect(HWND_DESKTOP);
 
         nWidth = vRect.xRight - vRect.xLeft;
         nHeight = vRect.yTop - vRect.yBottom;
 
-        SetSize( nWidth
-                ,nHeight
-               );
+        SetSize( nWidth, nHeight );
 
         //
         // Now flush the window style cache and actually go full-screen
@@ -937,21 +961,17 @@ bool wxTopLevelWindowOS2::ShowFullScreen(
                           ,SWP_SIZE | SWP_MOVE
                          );
 
-        wxSizeEvent                 vEvent( wxSize( nWidth
-                                                   ,nHeight
-                                                  )
-                                           ,GetId()
-                                          );
-
+        wxSize full( nWidth, nHeight );
+        wxSizeEvent vEvent( full, GetId() );
         GetEventHandler()->ProcessEvent(vEvent);
-        return TRUE;
+        return true;
     }
     else
     {
         if (!IsFullScreen())
-            return FALSE;
+            return false;
 
-        m_bFsIsShowing = FALSE;
+        m_bFsIsShowing = false;
         Maximize(m_bFsIsMaximized);
         ::WinSetWindowULong( (HWND)GetHWND()
                             ,QWL_STYLE
@@ -965,7 +985,7 @@ bool wxTopLevelWindowOS2::ShowFullScreen(
                           ,m_vFsOldSize.height
                           ,SWP_SIZE | SWP_MOVE
                          );
-        return TRUE;
+        return true;
     }
 } // end of wxTopLevelWindowOS2::ShowFullScreen
 
@@ -1018,7 +1038,7 @@ bool wxTopLevelWindowOS2::EnableCloseButton(
     if (!hMenu)
     {
         wxLogLastError(_T("GetSystemMenu"));
-        return FALSE;
+        return false;
     }
 
     //
@@ -1046,7 +1066,7 @@ bool wxTopLevelWindowOS2::EnableCloseButton(
                  ,(MPARAM)FCF_MENU
                  ,(MPARAM)0
                 );
-    return TRUE;
+    return true;
 } // end of wxTopLevelWindowOS2::EnableCloseButton
 
 // ============================================================================
@@ -1060,7 +1080,7 @@ bool wxTLWHiddenParentModule::OnInit()
 {
     m_shWnd = NULL;
     m_szClassName = NULL;
-    return TRUE;
+    return true;
 } // end of wxTLWHiddenParentModule::OnInit
 
 void wxTLWHiddenParentModule::OnExit()
