@@ -4,7 +4,7 @@
 // Author:      David Webster
 // Modified by:
 // Created:     09/17/99
-// RCS-ID:      $Id: utils.cpp,v 1.65 2005/04/27 01:19:43 DW Exp $
+// RCS-ID:      $Id: utils.cpp,v 1.68 2005/09/01 17:04:08 ABX Exp $
 // Copyright:   (c) David Webster
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -39,16 +39,19 @@
 
 #define PURE_32
 
-#ifndef __EMX__
-#include <upm.h>
-#include <netcons.h>
-#include <netbios.h>
+#if defined(__WATCOMC__)
+extern "C"
+{
+    #include <upm.h>
+}
+#elif !defined(__EMX__)
+    #include <upm.h>
+    #include <netcons.h>
+    #include <netbios.h>
 #endif
 
 static const wxChar WX_SECTION[] = _T("wxWidgets");
 static const wxChar eHOSTNAME[]  = _T("HostName");
-static const wxChar eUSERID[]    = _T("UserId");
-static const wxChar eUSERNAME[]  = _T("UserName");
 
 // For the following functions we SHOULD fill in support
 // for Windows-NT (which I don't know) as I assume it begin
@@ -99,41 +102,30 @@ bool wxGetHostName(
 }
 
 // Get user ID e.g. jacs
-bool wxGetUserId(
-  wxChar*                           zBuf
-, int                               nType
-)
+bool wxGetUserId(wxChar* zBuf, int nType)
 {
-#if defined(__VISAGECPP__)
-    long                            lrc;
+#if defined(__VISAGECPP__) || defined(__WATCOMC__)
     // UPM procs return 0 on success
-    lrc = U32ELOCU((unsigned char*)zBuf, (unsigned long *)&nType);
+    long lrc = U32ELOCU((PUCHAR)zBuf, (PULONG)&nType);
     if (lrc == 0) return true;
 #endif
     return false;
 }
 
-bool wxGetUserName(
-  wxChar*                           zBuf
-, int                               nMaxSize
-)
+bool wxGetUserName( wxChar* zBuf, int nMaxSize )
 {
 #ifdef USE_NET_API
-    wxGetUserId( zBuf
-                ,nMaxSize
-               );
+    wxGetUserId( zBuf, nMaxSize );
 #else
     wxStrncpy(zBuf, _T("Unknown User"), nMaxSize);
 #endif
     return true;
 }
 
-int wxKill(
-  long                              lPid
-, wxSignal                          eSig
-, wxKillError*                      peError
-, int                               flags
-)
+int wxKill(long         lPid,
+           wxSignal     WXUNUSED(eSig),
+           wxKillError* WXUNUSED(peError),
+           int          WXUNUSED(flags))
 {
     return((int)::DosKillProcess(0, (PID)lPid));
 }
@@ -198,7 +190,7 @@ bool wxShell(
 }
 
 // Shutdown or reboot the PC
-bool wxShutdown(wxShutdownFlags wFlags)
+bool wxShutdown(wxShutdownFlags WXUNUSED(wFlags))
 {
     // TODO
     return false;
@@ -219,10 +211,10 @@ wxBatteryState wxGetBatteryState()
 // Get free memory in bytes, or -1 if cannot determine amount (e.g. on UNIX)
 wxMemorySize wxGetFreeMemory()
 {
-    void*                           pMemptr = NULL;
-    LONG                            lSize;
-    ULONG                           lMemFlags;
-    APIRET                          rc;
+    void* pMemptr = NULL;
+    LONG  lSize;
+    ULONG lMemFlags;
+    APIRET rc;
 
     lMemFlags = PAG_FREE;
     rc = ::DosQueryMem(pMemptr, (PULONG)&lSize, &lMemFlags);
@@ -275,6 +267,8 @@ bool wxSetEnv(const wxString& variable, const wxChar *value)
 
     return putenv(buf) == 0;
 #else // no way to set an env var
+    wxUnusedVar(variable);
+    wxUnusedVar(value);
     return false;
 #endif
 }
@@ -368,12 +362,34 @@ void wxBell()
     DosBeep(1000,1000); // 1kHz during 1 sec.
 }
 
+wxString wxGetOsDescription()
+{
+    wxString strVer(_T("OS/2"));
+    ULONG ulSysInfo[QSV_MAX] = {0};
 
-void wxAppTraits::InitializeGui(unsigned long &ulHab)
+    if (::DosQuerySysInfo( 1L,
+                           QSV_MAX,
+                           (PVOID)ulSysInfo,
+                           sizeof(ULONG) * QSV_MAX
+                         ) == 0L )
+    {
+        wxString ver;
+        ver.Printf( _T(" ver. %d.%d rev. %c"),
+                    int(ulSysInfo[QSV_VERSION_MAJOR] / 10),
+                    int(ulSysInfo[QSV_VERSION_MINOR]),
+                    char(ulSysInfo[QSV_VERSION_REVISION])
+                  );
+        strVer += ver;
+    }
+
+    return strVer;
+}
+
+void wxAppTraits::InitializeGui(unsigned long &WXUNUSED(ulHab))
 {
 }
 
-void wxAppTraits::TerminateGui(unsigned long ulHab)
+void wxAppTraits::TerminateGui(unsigned long WXUNUSED(ulHab))
 {
 }
 
@@ -428,12 +444,14 @@ const wxChar* wxGetHomeDir(
 }
 
 // Hack for OS/2
-wxChar* wxGetUserHome (
-  const wxString&                   rUser
-)
+#if wxUSE_UNICODE
+const wxMB2WXbuf wxGetUserHome( const wxString &rUser )
+#else // just for binary compatibility -- there is no 'const' here
+wxChar* wxGetUserHome ( const wxString &rUser )
+#endif
 {
-    wxChar*                         zHome;
-    wxString                        sUser1(rUser);
+    wxChar*    zHome;
+    wxString   sUser1(rUser);
 
     wxChar *wxBuffer = new wxChar[256];
 #ifndef __EMX__
@@ -455,7 +473,7 @@ wxChar* wxGetUserHome (
                     return *zHome ? zHome : (wxChar*)_T("\\");
             }
             if (wxStricmp(zTmp, WXSTRINGCAST sUser1) == 0)
-                sUser1 = _T("");
+                sUser1 = wxEmptyString;
         }
     }
 #endif
@@ -465,18 +483,22 @@ wxChar* wxGetUserHome (
         {
             wxStrcpy(wxBuffer, zHome);
             wxUnix2DosFilename(wxBuffer);
+#if wxUSE_UNICODE
+            wxWCharBuffer retBuffer (wxBuffer);
+            delete[] wxBuffer;
+            return retBuffer;
+#else
             wxStrcpy(zHome, wxBuffer);
             delete[] wxBuffer;
             return zHome;
+#endif
         }
     }
     delete[] wxBuffer;
     return (wxChar*)wxEmptyString; // No home known!
 }
 
-wxString WXDLLEXPORT wxPMErrorToStr(
-  ERRORID                           vError
-)
+wxString WXDLLEXPORT wxPMErrorToStr(ERRORID vError)
 {
     wxString                        sError;
 
@@ -536,7 +558,7 @@ wxString WXDLLEXPORT wxPMErrorToStr(
 // to be used by all X11 based ports.
 struct wxEndProcessData;
 
-void wxHandleProcessTermination(wxEndProcessData *proc_data)
+void wxHandleProcessTermination(wxEndProcessData *WXUNUSED(proc_data))
 {
     // For now, just do nothing. To be filled in as needed.
 }
