@@ -3,7 +3,7 @@
 // Purpose:     wxString unit test
 // Author:      Vadim Zeitlin, Wlodzimierz ABX Skiba
 // Created:     2004-04-19
-// RCS-ID:      $Id: strings.cpp,v 1.26 2005/04/11 09:13:11 RN Exp $
+// RCS-ID:      $Id: strings.cpp,v 1.28.2.2 2006/02/15 21:10:08 MW Exp $
 // Copyright:   (c) 2004 Vadim Zeitlin, Wlodzimierz Skiba
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -53,6 +53,9 @@ private:
         CPPUNIT_TEST( CaseChanges );
         CPPUNIT_TEST( Compare );
         CPPUNIT_TEST( CompareNoCase );
+        CPPUNIT_TEST( ToLong );
+        CPPUNIT_TEST( ToULong );
+        CPPUNIT_TEST( ToDouble );
     CPPUNIT_TEST_SUITE_END();
 
     void String();
@@ -75,6 +78,9 @@ private:
     void CaseChanges();
     void Compare();
     void CompareNoCase();
+    void ToLong();
+    void ToULong();
+    void ToDouble();
 
 #if wxUSE_WCHAR_T
     // test if converting s using the given encoding gives ws and vice versa
@@ -222,6 +228,20 @@ void StringTestCase::Conversion()
 #endif
 }
 
+#if !wxUSE_UNICODE
+// in case wcscmp is missing
+//
+static int wx_wcscmp(const wchar_t *s1, const wchar_t *s2)
+{
+    while (*s1 == *s2 && *s1 != 0)
+    {
+        s1++;
+        s2++;
+    }
+    return *s1 - *s2;
+}
+#endif
+
 void
 StringTestCase::DoTestConversion(const char *s,
                                  const wchar_t *ws,
@@ -240,7 +260,7 @@ StringTestCase::DoTestConversion(const char *s,
         wxWCharBuffer wbuf(wxString(s).wc_str(conv));
 
         if ( ws )
-            CPPUNIT_ASSERT( wcscmp(wbuf, ws) == 0 );
+            CPPUNIT_ASSERT( wx_wcscmp(wbuf, ws) == 0 );
         else
             CPPUNIT_ASSERT( !*wbuf );
     }
@@ -529,8 +549,11 @@ void StringTestCase::CaseChanges()
     if ( locRu.IsOk() )
     {
         // try upper casing 8bit strings
-        wxString sUpper("\xdf"),
-                 sLower("\xff");
+        const wchar_t capital_ya[] = { 0x42f, 0 },
+                      small_ya[]   = { 0x44f, 0 };
+
+        wxString sUpper(wxConvLibc.cWC2MB(capital_ya)),
+                 sLower(wxConvLibc.cWC2MB(small_ya));
 
         CPPUNIT_ASSERT( sUpper.Lower() == sLower );
         CPPUNIT_ASSERT( sLower.Upper() == sUpper );
@@ -620,3 +643,94 @@ void StringTestCase::CompareNoCase()
     CPPUNIT_CNCNEQ_ASSERT( s1, neq3 );
 }
 
+void StringTestCase::ToLong()
+{
+    long l;
+    static const struct ToLongData
+    {
+        const wxChar *str;
+        long value;
+        bool ok;
+    } longData[] =
+    {
+        { _T("1"), 1, true },
+        { _T("0"), 0, true },
+        { _T("a"), 0, false },
+        { _T("12345"), 12345, true },
+        { _T("-1"), -1, true },
+        { _T("--1"), 0, false },
+    };
+
+    size_t n;
+    for ( n = 0; n < WXSIZEOF(longData); n++ )
+    {
+        const ToLongData& ld = longData[n];
+        CPPUNIT_ASSERT_EQUAL( ld.ok, wxString(ld.str).ToLong(&l) );
+        if ( ld.ok )
+            CPPUNIT_ASSERT_EQUAL( ld.value, l );
+    }
+}
+
+void StringTestCase::ToULong()
+{
+    unsigned long ul;
+    static const struct ToULongData
+    {
+        const wxChar *str;
+        unsigned long value;
+        bool ok;
+    } ulongData[] =
+    {
+        { _T("1"), 1, true },
+        { _T("0"), 0, true },
+        { _T("a"), 0, false },
+        { _T("12345"), 12345, true },
+        // this is surprizing but consistent with strtoul() behaviour
+        { _T("-1"), ULONG_MAX, true },
+    };
+
+    size_t n;
+    for ( n = 0; n < WXSIZEOF(ulongData); n++ )
+    {
+        const ToULongData& uld = ulongData[n];
+        CPPUNIT_ASSERT_EQUAL( uld.ok, wxString(uld.str).ToULong(&ul) );
+        if ( uld.ok )
+            CPPUNIT_ASSERT_EQUAL( uld.value, ul );
+    }
+}
+
+void StringTestCase::ToDouble()
+{
+    double d;
+    static const struct ToDoubleData
+    {
+        const wxChar *str;
+        double value;
+        bool ok;
+    } doubleData[] =
+    {
+        { _T("1"), 1, true },
+        { _T("1.23"), 1.23, true },
+        { _T(".1"), .1, true },
+        { _T("1."), 1, true },
+        { _T("1.."), 0, false },
+        { _T("0"), 0, true },
+        { _T("a"), 0, false },
+        { _T("12345"), 12345, true },
+        { _T("-1"), -1, true },
+        { _T("--1"), 0, false },
+    };
+
+    // we need to use decimal point, not comma or whatever is its value for the
+    // current locale
+    wxSetlocale(LC_ALL, _T("C"));
+
+    size_t n;
+    for ( n = 0; n < WXSIZEOF(doubleData); n++ )
+    {
+        const ToDoubleData& ld = doubleData[n];
+        CPPUNIT_ASSERT_EQUAL( ld.ok, wxString(ld.str).ToDouble(&d) );
+        if ( ld.ok )
+            CPPUNIT_ASSERT_EQUAL( ld.value, d );
+    }
+}
